<?php
/** admin/main.php
 *
 * License: All file in admin folder is also GPL.
 *
*/

// Load defaults value
require_once(dirname(__FILE__) . "/defaults.php");


// Tell WordPress to load this file if user is in admin area.
if( is_admin() ) {

// Load the settings
require_once(dirname(__FILE__) . "/settings.php");

// Load the sanitize functions
require_once(dirname(__FILE__) . "/sanitize.php");

}

// Getting the defaults theme options
function malvouz_get_theme_options() {
	global $malvouz_defaults;
	$optionsMalvouz = get_option( 'ma_options', $malvouz_defaults );
	$optionsMalvouz = array_merge($malvouz_defaults, $optionsMalvouz);
	
	return $optionsMalvouz;
}

$malvouz_options = malvouz_get_theme_options();
foreach ($malvouz_options as $key => $value) {
	${"$key"} = $value;
}

// Add Admin Hook
add_action( 'admin_init', 'malvouz_init_z' );
add_action( 'admin_menu', 'malvouz_add_page_z' );

$malvouz_options = malvouz_get_theme_options();

// Registering and enqueue all scripts
function malvouz_add_page_z() {
	// add_theme_page( $page_title, $menu_title, $capability, $menu_slug, $function );
	$page = add_theme_page('Malvouz Options', 'Malvouz Options', 'edit_theme_options', 'malvouz-page', 'malvouz_page_z');
	add_action ( 'admin_print_styles-'.$page, 'malvouz_admin_styles' );
	add_action ( 'admin_print_styles-'.$page, 'malvouz_admin_scripts' );
}

function malvouz_admin_styles() {
	wp_register_style( 'malvouz-admin-style',get_template_directory_uri() . '/admin/css/admin.css' );
	wp_register_style( 'jquery-ui-style',get_template_directory_uri() . '/js/jqueryui/css/ui-lightness/jquery-ui-1.8.16.custom.css' );
	wp_enqueue_style( 'malvouz-admin-style' );
	wp_enqueue_style( 'jquery-ui-style' );
}

function malvouz_admin_scripts() {
	// The farbtastic color selector already included in WP 
	wp_enqueue_script( 'farbtastic');
	wp_enqueue_style( 'farbtastic' );
	//Jquery accordion and slider libraries alreay included in WP
    wp_enqueue_script('jquery-ui-accordion');
	wp_enqueue_script('jquery-ui-slider');	
	// For backwards compatibility where WordPress is installed on older versions of WP where the ui accordion and slider are not included
	if (!wp_script_is('jquery-ui-accordion',$list='registered')) {
		wp_register_script('malvouz_accordion',get_template_directory_uri() . '/admin/js/accordion-slider.js', array('jquery') );
		wp_enqueue_script('malvouz_accordion');
		}	
	// For the WP uploader
	wp_enqueue_script('media-upload');
	wp_enqueue_script('thickbox');
	wp_enqueue_style('thickbox');	
	// The js used in the admin
	wp_register_script('malvouz-admin-js',get_template_directory_uri() . '/admin/js/admin.js' );
	wp_enqueue_script('malvouz-admin-js');
}

// Start to define malvouz_init_z() function
function malvouz_init_z() {
	register_setting( 'ma_options', 'ma_options', 'ma_options_validate' );
	
	/*
	 *
	 * Start to add section (menu) with add_settings_section( $id, $title, $callback, $page )
	 * Start child of section with add_settings_field( $id, $title, $callback, $page, $section, $args )
	 *
	 */
	 
	add_settings_section( 'header_section', __('General', 'malvouz'), 'malvouz_section_header_z', __FILE__ );
	add_settings_section( 'slider_section', __('Image Slider', 'malvouz'), 'malvouz_section_slider_z', __FILE__ );
	
	// Header section
	add_settings_field( 'malvouz_logo', __('Logo', 'malvouz'), 'malvouz_logo_z' , __FILE__, 'header_section');
	add_settings_field( 'malvouz_favico', __('Fav Icon', 'malvouz'), 'malvouz_favico_z' , __FILE__, 'header_section');
	add_settings_field( 'malvouz_slider_display', __('Slider Display', 'malvouz'), 'malvouz_slider_display_z' , __FILE__, 'header_section');
	add_settings_field( 'malvouz_slider_thumbnail', __('Slider Thumbnail', 'malvouz'), 'malvouz_slider_thumbnail_z' , __FILE__, 'header_section');
	
	// Slider Section
	add_settings_field( 'malvouz_image1', __('Image 1', 'malvouz'), 'malvouz_image_1_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title1', __('Title 1', 'malvouz'), 'malvouz_title_1_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link1', __('Link 1', 'malvouz'), 'malvouz_link_1_z', __FILE__, 'slider_section' );
	
	add_settings_field( 'malvouz_image2', __('Image 2', 'malvouz'), 'malvouz_image_2_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title2', __('Title 2', 'malvouz'), 'malvouz_title_2_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link2', __('Link 2', 'malvouz'), 'malvouz_link_2_z', __FILE__, 'slider_section' );
	
	add_settings_field( 'malvouz_image3', __('Image 3', 'malvouz'), 'malvouz_image_3_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title3', __('Title 3', 'malvouz'), 'malvouz_title_3_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link3', __('Link 3', 'malvouz'), 'malvouz_link_3_z', __FILE__, 'slider_section' );
	
	add_settings_field( 'malvouz_image4', __('Image 4', 'malvouz'), 'malvouz_image_4_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title4', __('Title 4', 'malvouz'), 'malvouz_title_4_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link4', __('Link 4', 'malvouz'), 'malvouz_link_4_z', __FILE__, 'slider_section' );
	
	add_settings_field( 'malvouz_image5', __('Image 5', 'malvouz'), 'malvouz_image_5_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title5', __('Title 5', 'malvouz'), 'malvouz_title_5_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link5', __('Link 5', 'malvouz'), 'malvouz_link_5_z', __FILE__, 'slider_section' );
	
	add_settings_field( 'malvouz_image6', __('Image 6', 'malvouz'), 'malvouz_image_6_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title6', __('Title 6', 'malvouz'), 'malvouz_title_6_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link6', __('Link 6', 'malvouz'), 'malvouz_link_6_z', __FILE__, 'slider_section' );
	
	add_settings_field( 'malvouz_image7', __('Image 7', 'malvouz'), 'malvouz_image_7_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title7', __('Title 7', 'malvouz'), 'malvouz_title_7_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link7', __('Link 7', 'malvouz'), 'malvouz_link_7_z', __FILE__, 'slider_section' );
	
	add_settings_field( 'malvouz_image8', __('Image 8', 'malvouz'), 'malvouz_image_8_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title8', __('Title 8', 'malvouz'), 'malvouz_title_8_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link8', __('Link 8', 'malvouz'), 'malvouz_link_8_z', __FILE__, 'slider_section' );
	
	add_settings_field( 'malvouz_image9', __('Image 9', 'malvouz'), 'malvouz_image_9_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title9', __('Title 9', 'malvouz'), 'malvouz_title_9_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link9', __('Link 9', 'malvouz'), 'malvouz_link_9_z', __FILE__, 'slider_section' );
	
	add_settings_field( 'malvouz_image10', __('Image 10', 'malvouz'), 'malvouz_image_10_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_title10', __('Title 10', 'malvouz'), 'malvouz_title_10_z', __FILE__, 'slider_section' );
	add_settings_field( 'malvouz_link10', __('Link 10', 'malvouz'), 'malvouz_link_10_z', __FILE__, 'slider_section' );
	
}

// Start do define malvouz_page_z function
function malvouz_page_z() {
	if ( isset( $_GET['settings-updated'] ) ) {
		echo "<div class='updated fade' style='clear:left;'><p>";
		echo _e('Malvouz options updated successfully', 'malvouz');
		echo "</p></div>";
	}
	?>
	
	<div id="icon-themes" class="icon32">
		<br>
	</div>
	
	<h2 class="nav-tab-active">Malvouz Options</h2>
	
	<div id="main-options">
	<form name="malvouz_form" action="options.php" method="post" enctype="multipart/form-data">
	<div id="accordion">
	<?php settings_fields( 'ma_options' );
	do_settings_sections(__FILE__);
	?>
	</div>
	
	<div id="submitDiv">
		<input class="button" name="ma_options[malvouz_defaults]" id="malvouz_defaults" type="submit" style="float:left;" value="<?php _e('Reset to Defaults','malvouz'); ?>" />
		<input class="button button-primary" name="ma_options[malvouz_submit]" type="submit" style="float:right;" value="<?php _e( 'Save Changes' ,'malvouz'); ?>" />
	</div> <!-- end submitDiv -->
	</form> <!-- end form -->
	</div> <!-- end main-options -->
	
	
	<?php 
	/*
	 * Adding script for color javascript
	 *
	 */
	?>
	<script>
	// Add ID below this comment

	function startfarb(a,b) {
	jQuery(b).css('display','none');	
	jQuery(b).farbtastic(a);
	
	jQuery(a).click(function() {
			if(jQuery(b).css('display') == 'none')	jQuery(b).show(300);
		});

	jQuery(document).mousedown( function() {
			jQuery(b).hide(700);
		});
}
</script>

<?php }