<?php
/**	theme-functions.php
 *
 * 
 *	Include sidebar, start setup, 
 * 
 * 	@author		Malvouz
 * 	@package	Hanamoto
 * 	@since		1.0.0 - 07.04.2013
 */
 
if ( ! function_exists( 'malvz_setup' ) ):

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @author	WordPress.org
 * @since	1.0.0 - 05.02.2012
 *
 * @return	void
 */

function malvz_setup() {
	global $content_width;
	
	if ( ! isset( $content_width ) ) {
		$content_width = 620;
	}
	
	add_editor_style();
	
	add_theme_support( 'automatic-feed-links' );
		
	add_theme_support( 'post-thumbnails' );
		
	add_theme_support( 'malvz_hooks', array( 'all' ) );
	
	
	/**
	* Custom Nav Menu handler for the Navbar by Konstantin Obeland
	*/
	require_once( get_template_directory() . '/inc/nav-menu-walker.php' );

	register_nav_menus( array(
		'header-menu'  	=>	__( 'Header Menu', 'hanamoto' )
	));
	
	/**
 * Add Custom Background
 */
 
	$args = array(
	'default-color'          => 'ffffff',
	'default-image'          => '',
	'wp-head-callback'       => '_custom_background_cb',
	'admin-head-callback'    => '',
	'admin-preview-callback' => ''
);

add_theme_support( 'custom-background', $args );

}
endif;

add_action( 'after_setup_theme', 'malvz_setup' ); 


/**
 * Creates a nicely formatted and more specific title element text
 * for output in head of document, based on current view.
 *
 * This code taken from Twenty Twelve themes.
 */

function malvz_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'hanamoto' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'malvz_wp_title', 10, 2 );

	/* Added when users empty for title. */

	function hanamoto_title($title) {
	if ($title == '') {
	return 'Untitled';
	} else {
	return $title;
	}
	}
	add_filter('the_title', 'hanamoto_title');
	
/**
 * Add Sidebar Function
 */
add_action( 'widgets_init', 'malvz_widgets_init' );

function malvz_widgets_init() {	
	register_sidebar( array (
		'name' => __( 'Sidebar Widget', 'hanamoto' ),
		'id' => 'sidebar-widget',
		'before_widget' => '<div class="widget-wrapper"><div id="%1s"><div class="%2s">',
		'after_widget' => '</div></div></div>',
		'before_title' => '<div class="widget-title"><h5>',
		'after_title' => '</h5></div><div class="clear"></div>'
	));
}
		
/**
 * Add Jquery and Custom JavaScript
 */
add_action('wp_enqueue_scripts', 'java_script');

function java_script(){
	
	/* Register Javascript */
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') );
	wp_enqueue_script( 'easing', get_template_directory_uri() . '/js/flexslider/jquery.easing.js', array('jquery') );
	wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/js/flexslider/modernizr.js', array('jquery') );
	wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/js/flexslider/jquery.flexslider.js', array('jquery') );
	wp_enqueue_script( 'mousewheel', get_template_directory_uri() . '/js/flexslider/jquery.mousewheel.js', array('jquery') );
	wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/fitvids.js', array('jquery') );
	wp_enqueue_style( 'bootcss', get_template_directory_uri() . '/css/bootstrap.css', array(), '20131107', 'all' );
	wp_enqueue_style( 'stylecss', get_stylesheet_uri(), array(), '20131107', 'all' );
	wp_enqueue_style( 'bootrescss', get_template_directory_uri() . '/css/bootstrap-responsive.css', array(), '20131107', 'all' );
	wp_enqueue_style( 'flexcss', get_template_directory_uri() . '/css/flexslider.css', array(), '20131107', 'all' );
	
}


/**
 * Comments
 */
 
/* Comments -- Template Comments */
if ( ! function_exists( 'malvz_comment' ) ) :

/* Comments -- Template for comments and pingbacks. */
function malvz_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-gravatar"><?php echo get_avatar( $comment, 60 ); ?></div>
		
		<div class="comment-body">
		<div class="comment-meta commentmetadata"><?php printf( __( '%s <span class="says">says</span>', 'hanamoto' ), sprintf( '<cite class="visitor-comment">%s</cite>', get_comment_author_link() ) ); ?> <a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
			<?php
				/* translators: 1: date, 2: time */
				printf( __( '%1$s at %2$s', 'hanamoto' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( 'Edit &rarr;', 'hanamoto' ), ' ' );
			?>
		</div>

		<?php comment_text(); ?>
		
		<?php if ( $comment->comment_approved == '0' ) : ?>
		<p class="moderation"><?php _e( 'Your comment is awaiting moderation.', 'hanamoto' ); ?></p>
		<?php endif; ?>

		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div><!-- .reply -->
		
		</div>
		<!--comment Body-->
		
	</div><!-- #comment-##  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'hanamoto' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('(Edit)', 'hanamoto'), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
endif;	

/*-----------------------------------------------------------------------------------*/
# Get Popular posts 
/*-----------------------------------------------------------------------------------*/
function wp_popular_posts($pop_posts = 5 , $thumb = true){
	global $wpdb , $post;
	$orig_post = $post;
	
	$popularposts = "SELECT ID,post_title,post_date,post_author,post_content,post_type FROM $wpdb->posts WHERE post_status = 'publish' AND post_type = 'post' ORDER BY comment_count DESC LIMIT 0,".$pop_posts;
	$posts = $wpdb->get_results($popularposts);
	if($posts){
		global $post;
		foreach($posts as $post){
		setup_postdata($post);?>
			<li>
			<?php if ( function_exists("has_post_thumbnail") && has_post_thumbnail() && $thumb ) : ?>			
				<div class="post-thumbnail">
					<a href="<?php echo get_permalink( $post->ID ) ?>" title="<?php printf( __( 'Permalink to %s', 'malvouz' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php malvouz_thumb('',50,50); ?></a>
				</div><!-- post-thumbnail /-->
			<?php endif; ?>
				<a href="<?php echo get_permalink( $post->ID ) ?>" title="<?php echo the_title(); ?>"><?php echo the_title(); ?></a>
			</li>
	<?php 
		}
	}
	$post = $orig_post;
}

/*-----------------------------------------------------------------------------------*/
# Get Most Racent posts
/*-----------------------------------------------------------------------------------*/
function wp_last_posts($numberOfPosts = 5 , $thumb = true){
	global $post;
	$orig_post = $post;
	
	$lastPosts = get_posts('numberposts='.$numberOfPosts);
	foreach($lastPosts as $post): setup_postdata($post);
?>
<li>
	<?php if ( function_exists("has_post_thumbnail") && has_post_thumbnail() && $thumb ) : ?>			
		<div class="post-thumbnail">
			<a href="<?php the_permalink(); ?>" title="<?php printf( __( 'Permalink to %s', 'malvouz' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php malvouz_thumb('',50,50); ?></a>
		</div><!-- post-thumbnail /-->
	<?php endif; ?>
	<h3><a href="<?php the_permalink(); ?>"><?php the_title();?></a></h3>
	<span class="date"><?php the_time(get_option('date_format')); ?></span>
</li>
<?php endforeach; 
	$post = $orig_post;
}

/*-----------------------------------------------------------------------------------*/
# Get Most commented posts 
/*-----------------------------------------------------------------------------------*/
function most_commented($comment_posts = 5 , $avatar_size = 50){
$comments = get_comments('status=approve&number='.$comment_posts);
foreach ($comments as $comment) { ?>
	<li>
		<div class="post-thumbnail">
			<?php echo get_avatar( $comment, $avatar_size ); ?>
		</div>
		<a href="<?php echo get_permalink($comment->comment_post_ID ); ?>#comment-<?php echo $comment->comment_ID; ?>">
		<?php echo strip_tags($comment->comment_author); ?>: <?php echo wp_html_excerpt( $comment->comment_content, 60 ); ?>... </a>
	</li>
<?php } 
}

/*-----------------------------------------------------------------------------------*/
# malvouz Thumb
/*-----------------------------------------------------------------------------------*/
function malvouz_thumb($img='' , $width='' , $height=''){
	global $post;
		$image_id = get_post_thumbnail_id($post->ID);  
		$image_url = wp_get_attachment_image($image_id, array($width,$height), false, array( 'alt'   => get_the_title() ,'title' =>  get_the_title()  ));  
		echo $image_url;
}
